Learn R Programming

vglmer (version 1.0.5)

posterior_samples.vglmer: Draw samples from the variational distribution

Description

This function draws samples from the estimated variational distributions. If using MAVB to improve the quality of the approximating distribution, please use MAVB or predict_MAVB.

Usage

posterior_samples.vglmer(object, samples, verbose = FALSE)

Value

This function returns a matrix with samples rows and columns for each fixed and random effect.

Arguments

object

Model fit using vglmer.

samples

Number of samples to draw.

verbose

Show progress in drawing samples.